==> timi-0.3.0-20170520.230316-1.jar: timi/server/web/routes.clj <==
(ns timi.server.web.routes
  (:require
    [compojure.core :refer [GET POST context defroutes routes]]
    [ring.util.mime-type :as mime]
    [ring.util.response :as response]
    [timi.server.web.screens.time :as time-screen]
    [timi.server.web.screens.projects :as projects-screen]
    [timi.server.web.screens.reports :as reports-screen]
    [timi.server.infra.date-time :refer [today format-date str->local-date]]))

(defroutes time-routes
  (context "/time" []
    (GET "/activity-graphic"
         request
         (time-screen/activity-graphic request))
    (GET "/day-entries"
         request
         (time-screen/day-entries-table request))
    (GET "/"
         request
         (response/redirect (str "/time/" (format-date (today)))))
    (GET "/:for-date"
         [for-date :<< str->local-date :as request]
         (time-screen/get-page for-date request))
    (POST "/:for-date"
          request
          (time-screen/post request))))

(defroutes projects-routes
  (GET "/projects"
       request
       (projects-screen/get-page request)))

(defroutes reports-routes
  (GET "/reports"
       request
       (reports-screen/get-page request)))

(defroutes default-routes
  (GET "/*" {{resource-path :*} :route-params}
       (fn [req]
         (let [resp (some->
                      (response/resource-response (str "public/" resource-path))
                      ((fn [resp]
                         (if-let [mime-type (mime/ext-mime-type resource-path)]
                           (response/content-type resp mime-type)
                           resp))))]
           (if resp
             resp
             (response/not-found (str "Could not find " resource-path)))))))

(defroutes all
  (GET "/"
       []
       (response/redirect "/time"))
  (routes time-routes
          projects-routes
          reports-routes
          default-routes))

==> timi-0.3.0-20170522.163612-2.jar: timi/server/web/routes.clj <==
(ns timi.server.web.routes
  (:require
    [compojure.core :refer [GET POST context defroutes routes]]
    [ring.util.mime-type :as mime]
    [ring.util.response :as response]
    [timi.server.web.screens.docs :as docs-screen]
    [timi.server.web.screens.projects :as projects-screen]
    [timi.server.web.screens.reports :as reports-screen]
    [timi.server.web.screens.time :as time-screen]
    [timi.server.infra.date-time :refer [today format-date str->local-date]]))

(defroutes time-routes
  (context "/time" []
    (GET "/activity-graphic"
         request
         (time-screen/activity-graphic request))
    (GET "/day-entries"
         request
         (time-screen/day-entries-table request))
    (GET "/"
         request
         (response/redirect (str "/time/" (format-date (today)))))
    (GET "/:for-date"
         [for-date :<< str->local-date :as request]
         (time-screen/get-page for-date request))
    (POST "/:for-date"
          request
          (time-screen/post request))))

(defroutes docs-routes
  (GET "/docs"
       request
       (docs-screen/get-page request))
  (GET "/docs/*"
       request
       (docs-screen/get-page
         request
         (get-in request [:route-params :*]))))

(defroutes projects-routes
  (GET "/projects"
       request
       (projects-screen/get-page request)))

(defroutes reports-routes
  (GET "/reports"
       request
       (reports-screen/get-page request)))

(defroutes default-routes
  (GET "/*"
       {{resource-path :*} :route-params}
       (fn [req]
         (let [resp (some->
                      (response/resource-response
                        (str "public/" resource-path))
                      ((fn [resp]
                         (if-let [mime-type (mime/ext-mime-type resource-path)]
                           (response/content-type resp mime-type)
                           resp))))]
           (or
             resp
             (response/not-found
               (str "Could not find " resource-path)))))))

(defroutes all
  (GET "/"
       []
       (response/redirect "/time"))
  (GET "/authorize"
       request
       request)
  (GET "/logout"
       {session :session}
       (-> "/"
           (response/redirect)
           (assoc :session (dissoc session :identity))))
  (routes time-routes
          docs-routes
          projects-routes
          reports-routes
          default-routes))
